@@ -415,7 +415,15 @@ public class DownloadService extends Service {
 		if (Build.VERSION.SDK_INT < 26 || (powerManager != null && powerManager.isIgnoringBatteryOptimizations(intent.getPackage()))) {
 			context.startService(intent);
 		} else {
-			context.startForegroundService(intent);
+			try {
+				context.startForegroundService(intent);
+			} catch (IllegalStateException e) {
+				if (Build.VERSION.SDK_INT >= 31 && e instanceof android.app.ForegroundServiceStartNotAllowedException) {
+					Log.w(TAG, "ForegroundServiceStartNotAllowedException: " + e.getMessage());
+				} else {
+					throw e;
+				}
+			}
 		}
 	}
 	public static DownloadService getInstance() {
@@ -1543,7 +1551,17 @@ public class DownloadService extends Service {
 			Notifications.hidePlayingNotification(this, this, handler);
 		}
 		if(mRemoteControl != null) {
-			mRemoteControl.setPlaybackState(playerState.getRemoteControlClientPlayState(), getCurrentPlayingIndex(), size());
+			final int state = playerState.getRemoteControlClientPlayState();
+			final int index = getCurrentPlayingIndex();
+			final int queueSize = size();
+			handler.post(new Runnable() {
+				@Override
+				public void run() {
+					if(mRemoteControl != null) {
+						mRemoteControl.setPlaybackState(state, index, queueSize);
+					}
+				}
+			});
 		}
 
 		if (playerState == STARTED) {
