@@ -34,6 +34,8 @@ import java.util.SortedSet;
 import java.util.TreeSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import java.util.zip.DeflaterOutputStream;
 import java.util.zip.InflaterInputStream;
 
@@ -71,7 +73,7 @@ public class FileUtil {
 	private static final List<String> VIDEO_FILE_EXTENSIONS = Arrays.asList("flv", "mp4", "m4v", "wmv", "avi", "mov", "mpg", "mkv", "3gp", "webm");
 	private static final List<String> PLAYLIST_FILE_EXTENSIONS = Arrays.asList("m3u");
     private static final int MAX_FILENAME_LENGTH_V1 = 254 - ".complete.mp3".length();
-    private static final int MAX_FILENAME_LENGTH_V2 = 254 - "00-000-.complete.abcd".length();
+    private static final int MAX_FILENAME_LENGTH_V2 = 254 - "00-null-.complete.abcd".length();
     private static File DEFAULT_MUSIC_DIR;
 	private static final Kryo kryo = new Kryo();
 	private static HashMap<String, MusicDirectory.Entry> entryLookup;
@@ -142,7 +144,7 @@ public class FileUtil {
     }
 
     private static String getSongFileNameV1(Integer trackNumber, String title) {
-        String fileName = String.format(Locale.ROOT, "%02d-%s", trackNumber, title);
+        String fileName = trackNumber == null ? title : String.format(Locale.ROOT, "%02d-%s", trackNumber, title);
         if(fileName.length() >= MAX_FILENAME_LENGTH_V1) {
             fileName = fileName.substring(0, MAX_FILENAME_LENGTH_V1);
         }
@@ -157,6 +159,45 @@ public class FileUtil {
         return fileName;
     }
 
+    public static void parseFileNameIntoEntry(MusicDirectory.Entry entry, String fileName) {
+        String discNumber = null;
+        String trackNumber = null;
+        String title = null;
+
+		// tracknumber could be writte as null in v5.7.0 - dont think we can recover from this..
+        Pattern fileNameV2 = Pattern.compile("(\\d{2})-(\\d{3}|null)-(.+)");
+        Matcher matcher = fileNameV2.matcher(fileName);
+        if (matcher.matches()) {
+            discNumber = matcher.group(1);
+            trackNumber = matcher.group(2);
+            title = matcher.group(3);
+        } else {
+            Pattern fileNameV1 = Pattern.compile("(\\d{2})-(.+)");
+            matcher = fileNameV1.matcher(fileName);
+            if (matcher.matches()) {
+                trackNumber = matcher.group(1);
+                title = matcher.group(2);
+            }
+        }
+
+        if (discNumber != null) {
+            try {
+                entry.setDiscNumber(Integer.parseInt(discNumber));
+            } catch(Exception e) {
+                entry.setDiscNumber(1);
+            }
+        }
+        if (trackNumber != null) {
+            try {
+                entry.setTrack(Integer.parseInt(trackNumber));
+            } catch(Exception e) {
+            }
+        }
+        if (title != null) {
+            entry.setTitle(title);
+        }
+    }
+
     private static String getSongFileNameFull(String fileName, String stage, String extension) {
         if (stage != null) {
             fileName = fileName + "." + stage;
